@@ -1,4 +1,7 @@
 import os
+import shutil
+import tarfile
+import tempfile
 import backstage
 from backstage.venue import use_venue
 from backstage.venue import Venue
@@ -31,7 +34,9 @@ def new_act(venue, actname):
         return None
     os.mkdir(acthome)
     act = Act(venue, actname)
+    copy_act_skel(act)
     create_act_uwsgi_file(act)
+
     if act:
         s = 'created Backstage Act %s at %s' % (actname, acthome)
         print s
@@ -53,3 +58,18 @@ def create_act_uwsgi_file(act):
 
 def copy_act_skel(act):
     """copy the skeleton files into the Act instance folder"""
+    backstage_home = os.path.dirname(os.path.abspath(backstage.__file__))
+    act_skel = os.path.join(backstage_home,'skel/act')
+    #recursive copy via tar
+    tmpfile = tempfile.NamedTemporaryFile()
+    tmpfile.close()
+    tar_file = tarfile.open(tmpfile.name,'w')
+    cwd = os.getcwd()
+    os.chdir(act_skel)
+    tar_file.add('.')
+    os.chdir(cwd)
+    tar_file.close()
+    tar_file = tarfile.open(tmpfile.name,'r')
+    tar_file.extractall(act.acthome)
+    tar_file.close()
+    os.remove(tmpfile.name)
